@@ -2,7 +2,7 @@
 from __future__ import absolute_import, print_function
 
 from suanpan import asyncio
-from suanpan.api import app, component, oss
+from suanpan.api import app, component, oss, pdb
 from suanpan.api.hardware import Hardware
 from suanpan.api.requests import affinity, host
 from suanpan.api.sio import sio
