@@ -49,4 +49,8 @@ g = Context(
     backendPort=env.lazyget("SP_PORT", type=env.Int, default=7000),
     portStart=env.lazyget("SP_PORT_START", type=env.Int, default=10000),
     portEnd=env.lazyget("SP_PORT_END", type=env.Int, default=20000),
+    # service disable
+    serviceSioDisable=env.lazyget("SP_SERVICE_SIO_DISABLE", type=env.Bool, default=False),
+    serviceHttpDisable=env.lazyget("SP_SERVICE_HTTP_DISABLE", type=env.Bool, default=False),
+    serviceErgoEnable=env.lazyget("SP_SERVICE_ERGO_ENABLE", type=env.Bool, default=False),
 )
